pub struct Coptic;Expand description
The Coptic Calendar
The Coptic calendar, also called the Alexandrian Calendar, is a solar calendar that
is influenced by both the ancient Egpytian calendar and the Julian
calendar. It was introduced in Egypt under Roman rule in the first century BCE, and
replaced for civil use in 1875, however continues to be used liturgically.
This implementation extends proleptically for dates before the calendar’s creation.
This corresponds to the "coptic" CLDR calendar.
Era codes
This calendar uses a single code: am, corresponding to the After Diocletian/Anno Martyrum
era. 1 A.M. is equivalent to 284 C.E.
Months and days
The 13 months are called Thout (M01, 30 days), Paopi (M02, 30 days), Hathor (M03, 30 days),
Koiak (M04, 30 days), Tobi (M05, 30 days), Meshir (M06, 30 days), Paremhat (M07, 30 days),
Parmouti (M08, 30 days), Pashons (M09, 30 days), Paoni (M10, 30 days), Epip (M11, 30 days),
Mesori (M12, 30 days), Pi Kogi Enavot (M13, 5 days).
In leap years (years divisible by 4), Pi Kogi Enavot gains a 6th day.
Standard years thus have 365 days, and leap years 366.
Calendar drift
The Coptic calendar has the same year lengths and leap year rules as the Julian calendar, so it experiences the same drift of 1 day in ~128 years with respect to the seasons.
Implementations
Sourceimpl Coptic
impl Coptic
pub(crate) fn reference_year_from_month_day( month_code: ValidMonthCode, day: u8, ) -> Result<i32, EcmaReferenceYearError>